@@ -1,7 +1,7 @@
 from django.conf import settings
 from django.core.exceptions import SuspiciousOperation
 from django.contrib.sessions.backends.base import SessionBase, CreateError
-from .models import Session
+from django_couchdb_utils.sessions.models import Session
 from couchdbkit.exceptions import ResourceNotFound
 
 class SessionStore(SessionBase):
